<?php
/**
* 2010-2018 Webkul.
*
* NOTICE OF LICENSE
*
* All right is reserved,
* Please go through this link for complete license : https://store.webkul.com/license.html
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade this module to newer
* versions in the future. If you wish to customize this module for your
* needs please refer to https://store.webkul.com/customisation-guidelines/ for more information.
*
*  @author    Webkul IN <support@webkul.com>
*  @copyright 2010-2018 Webkul IN
*  @license   https://store.webkul.com/license.html
*/

if (!defined('_PS_VERSION_')) {
    exit;
}
require_once dirname(__FILE__).'/../wkfooterexploreblock/classes/WkCustomExploreLink.php';

class WkFooterExploreBlock extends Module
{
    const INSTALL_SQL_FILE = 'install.sql';
    public function __construct()
    {
        $this->name = 'wkfooterexploreblock';
        $this->tab = 'front_office_features';
        $this->version = '2.0.1';
        $this->author = 'webkul';
        $this->need_instance = 0;

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('Manage Custom Links');
        $this->description = $this->l('Shows custom links at footer explore block and navigation menu.');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }

    public function hookFooter()
    {
        $objCustomExploreLink = new WkCustomExploreLink();
        if ($exploreLinks = $objCustomExploreLink->getCustomExploreLinks(1, false, 2, 1)) {
            $this->context->controller->addCSS(_PS_MODULE_DIR_.$this->name.'/views/css/wkFooterExploreBlockFront.css');
            $this->context->smarty->assign('explore_links', $exploreLinks);
            return $this->display(__FILE__, 'wkFooterExploreBlock.tpl');
        }
    }

    /**
     * If admin add any language then an entry will add in defined $lang_tables array's lang table same as prestashop
     * @param array $params
     */
    public function hookActionObjectLanguageAddAfter($params)
    {
        if ($newIdLang = $params['object']->id) {
            $langTables = array('htl_custom_explore_link');
            //If Admin update new language when we do entry in module all lang tables.
            HotelHelper::updateLangTables($newIdLang, $langTables);
        }
    }

    public function hookDisplayAddModuleSettingLink()
    {
        $this->context->smarty->assign(
            'custom_explore_link_setting_url',
            $this->context->link->getAdminLink('AdminCustomExploreLinkSetting')
        );
        return $this->display(__FILE__, 'customExploreLinkSetting.tpl');
    }

    public function hookDisplayDefaultNavigationHook()
    {
        $objCustomExploreLink = new WkCustomExploreLink();
        if ($exploreLinks = $objCustomExploreLink->getCustomExploreLinks(1, false, 1)) {
            $this->context->smarty->assign('explore_links', $exploreLinks);
            return $this->display(__FILE__, 'hotelExternalNaviagtionMenu.tpl');
        }
    }

    public function install()
    {
        if (!file_exists(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE)) {
            return false;
        } elseif (!$sql = Tools::file_get_contents(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE)) {
            return false;
        }

        $sql = str_replace(array('PREFIX_',  'ENGINE_TYPE'), array(_DB_PREFIX_, _MYSQL_ENGINE_), $sql);
        $sql = preg_split("/;\s*[\r\n]+/", $sql);

        foreach ($sql as $query) {
            if ($query) {
                if (!Db::getInstance()->execute(trim($query))) {
                    return false;
                }
            }
        }
        $objCustomExploreLink = new WkCustomExploreLink();
        if (!parent::install()
            || !$this->callInstallTab()
            || !$this->registerModuleHooks()
            || !$objCustomExploreLink->insertDemoData()
        ) {
            return false;
        }
        return true;
    }

    public function registerModuleHooks()
    {
        return $this->registerHook(
            array (
                'footer',
                'displayAddModuleSettingLink',
                'actionObjectLanguageAddAfter',
                'displayDefaultNavigationHook'
            )
        );
    }

    public function callInstallTab()
    {
        //Controllers which are to be used in this modules but we have not to create tab for those Controllers...
        $this->installTab('AdminCustomExploreLinkSetting', 'Manage Custom Explore Links');
        return true;
    }

    public function installTab($class_name, $tab_name, $tab_parent_name = false)
    {
        $tab = new Tab();
        $tab->active = 1;
        $tab->class_name = $class_name;
        $tab->name = array();

        foreach (Language::getLanguages(true) as $lang) {
            $tab->name[$lang['id_lang']] = $tab_name;
        }

        if ($tab_parent_name) {
            $tab->id_parent = (int)Tab::getIdFromClassName($tab_parent_name);
        } else {
            $tab->id_parent = -1;
        }

        $tab->module = $this->name;
        $res = $tab->add();
        return $res;
    }

    public function uninstall()
    {
        if (!parent::uninstall()
            || !$this->uninstallTab()
            || !$this->dropTables()
        ) {
            return false;
        }

        return true;
    }

    public function uninstallTab()
    {
        $moduleTabs = Tab::getCollectionFromModule($this->name);
        if (!empty($moduleTabs)) {
            foreach ($moduleTabs as $moduleTab) {
                $moduleTab->delete();
            }
        }
        return true;
    }

    private function dropTables()
    {
        return Db::getInstance()->execute(
            'DROP TABLE IF EXISTS
            `'._DB_PREFIX_.'htl_custom_explore_link`,
            `'._DB_PREFIX_.'htl_custom_explore_link_lang`'
        );
    }
}
